@@ -42,12 +42,6 @@ try:
 except RuntimeError:  # libmpv found but version too old
     from . import mpv as mpv
 
-"""
-# check if MPV API v. 1
-if "libmpv.so.1" in mpv.sofile:
-    from . import mpv as mpv
-"""
-
 from PyQt5.QtCore import QT_VERSION_STR, PYQT_VERSION_STR
 from PyQt5.QtGui import QPixmap
 from PyQt5.QtWidgets import QMessageBox
