@@ -41,8 +41,8 @@ def events_snapshots(self):
     if observations are from media file and media files have video
     """
 
-    _, selected_observations = select_observations.select_observations(
-        self.pj, cfg.MULTIPLE, windows_title="Select observations for snapshots"
+    _, selected_observations = select_observations.select_observations2(
+        self, cfg.MULTIPLE, windows_title="Select observations for snapshots"
     )
     if not selected_observations:
         return
@@ -91,27 +91,32 @@ def events_snapshots(self):
     if not parameters[cfg.SELECTED_SUBJECTS] or not parameters[cfg.SELECTED_BEHAVIORS]:
         return
 
-    # Ask for time interval around the event
-    while True:
-        text, ok = QInputDialog.getDouble(
-            self, "Time interval around the events", "Time (in seconds):", 0.0, 0.0, 86400, 1
-        )
-        if not ok:
-            return
-        try:
-            time_interval = util.float2decimal(text)
-            break
-        except Exception:
-            QMessageBox.warning(self, cfg.programName, f"<b>{text}</b> is not recognized as time")
+    ib = dialog.Input_dialog(
+        label_caption="Choose parameters",
+        elements_list=[
+            ("dsb", "Time interval around the events (in seconds)", 0.0, 86400, 1, 0, 3),
+            ("il", "Bitmap format", (("JPG - small size / low quality", ""), ("PNG - big size / high quality", ""))),
+        ],
+        title="Extract frames",
+    )
+    if not ib.exec_():
+        return
+    time_interval = util.float2decimal(ib.elements["Time interval around the events (in seconds)"].value())
+    if "JPG" in ib.elements["Bitmap format"].currentText():
+        frame_bitmap_format = "jpg"
+    elif "PNG" in ib.elements["Bitmap format"].currentText():
+        frame_bitmap_format = "png"
+    else:
+        return
 
     # directory for saving frames
-    exportDir = QFileDialog().getExistingDirectory(
+    export_dir = QFileDialog().getExistingDirectory(
         self,
         "Choose a directory to extract events",
         os.path.expanduser("~"),
         options=QFileDialog(self).ShowDirsOnly,
     )
-    if not exportDir:
+    if not export_dir:
         return
 
     cursor = db_functions.load_events_in_db(
@@ -122,15 +127,15 @@ def events_snapshots(self):
         time_interval=cfg.TIME_FULL_OBS,
     )
 
-    for obsId in selected_observations:
+    for obs_id in selected_observations:
 
-        for nplayer in self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE]:
+        for nplayer in self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE]:
 
-            if not self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer]:
+            if not self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer]:
                 continue
             duration1 = []  # in seconds
-            for mediaFile in self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer]:
-                duration1.append(self.pj[cfg.OBSERVATIONS][obsId][cfg.MEDIA_INFO][cfg.LENGTH][mediaFile])
+            for mediaFile in self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer]:
+                duration1.append(self.pj[cfg.OBSERVATIONS][obs_id][cfg.MEDIA_INFO][cfg.LENGTH][mediaFile])
 
             for subject in parameters[cfg.SELECTED_SUBJECTS]:
 
@@ -138,7 +143,7 @@ def events_snapshots(self):
 
                     cursor.execute(
                         "SELECT occurence FROM events WHERE observation = ? AND subject = ? AND code = ?",
-                        (obsId, subject, behavior),
+                        (obs_id, subject, behavior),
                     )
                     rows = [{"occurence": util.float2decimal(r["occurence"])} for r in cursor.fetchall()]
 
@@ -153,22 +158,22 @@ def events_snapshots(self):
                         # check if media has video
                         flag_no_video = False
                         try:
-                            flag_no_video = not self.pj[cfg.OBSERVATIONS][obsId][cfg.MEDIA_INFO][cfg.HAS_VIDEO][
-                                self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]
+                            flag_no_video = not self.pj[cfg.OBSERVATIONS][obs_id][cfg.MEDIA_INFO][cfg.HAS_VIDEO][
+                                self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]
                             ]
                         except Exception:
                             flag_no_video = True
 
                         if flag_no_video:
                             logging.debug(
-                                f"Media {self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]} does not have video"
+                                f"Media {self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]} does not have video"
                             )
                             flag_no_video = True
                             response = dialog.MessageDialog(
                                 cfg.programName,
                                 (
                                     "The following media file does not have video.<br>"
-                                    f"{self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]}"
+                                    f"{self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]}"
                                 ),
                                 [cfg.OK, "Abort"],
                             )
@@ -180,12 +185,12 @@ def events_snapshots(self):
                         # check FPS
                         mediafile_fps = 0
                         try:
-                            if self.pj[cfg.OBSERVATIONS][obsId][cfg.MEDIA_INFO][cfg.FPS][
-                                self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]
+                            if self.pj[cfg.OBSERVATIONS][obs_id][cfg.MEDIA_INFO][cfg.FPS][
+                                self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]
                             ]:
                                 mediafile_fps = util.float2decimal(
-                                    self.pj[cfg.OBSERVATIONS][obsId][cfg.MEDIA_INFO][cfg.FPS][
-                                        self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]
+                                    self.pj[cfg.OBSERVATIONS][obs_id][cfg.MEDIA_INFO][cfg.FPS][
+                                        self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]
                                     ]
                                 )
                         except Exception:
@@ -193,13 +198,13 @@ def events_snapshots(self):
 
                         if not mediafile_fps:
                             logging.debug(
-                                f"FPS not found for {self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]}"
+                                f"FPS not found for {self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]}"
                             )
                             response = dialog.MessageDialog(
                                 cfg.programName,
                                 (
                                     "The FPS was not found for the following media file:<br>"
-                                    f"{self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]}"
+                                    f"{self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]}"
                                 ),
                                 [cfg.OK, "Abort"],
                             )
@@ -208,7 +213,7 @@ def events_snapshots(self):
                             if response == "Abort":
                                 return
 
-                        globalStart = (
+                        global_start = (
                             dec("0.000")
                             if row["occurence"] < time_interval
                             else round(row["occurence"] - time_interval, 3)
@@ -217,7 +222,7 @@ def events_snapshots(self):
                             row["occurence"]
                             - time_interval
                             - util.float2decimal(sum(duration1[0:mediaFileIdx]))
-                            - self.pj[cfg.OBSERVATIONS][obsId][cfg.TIME_OFFSET],
+                            - self.pj[cfg.OBSERVATIONS][obs_id][cfg.TIME_OFFSET],
                             3,
                         )
                         if start < time_interval:
@@ -226,11 +231,13 @@ def events_snapshots(self):
                         if cfg.POINT in behavior_state:
 
                             media_path = project_functions.full_path(
-                                self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx],
+                                self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx],
                                 self.projectFileName,
                             )
 
                             vframes = 1 if not time_interval else int(mediafile_fps * time_interval * 2)
+                            if vframes == 0:
+                                vframes = 1
 
                         if cfg.STATE in behavior_state:
                             if idx % 2 == 0:
@@ -258,13 +265,13 @@ def events_snapshots(self):
                                     if response == "Abort":
                                         return
 
-                                globalStop = round(rows[idx + 1]["occurence"] + time_interval, 3)
+                                # globalStop = round(rows[idx + 1]["occurence"] + time_interval, 3)
 
                                 stop = round(
                                     rows[idx + 1]["occurence"]
                                     + time_interval
                                     - util.float2decimal(sum(duration1[0:mediaFileIdx]))
-                                    - self.pj[cfg.OBSERVATIONS][obsId][cfg.TIME_OFFSET],
+                                    - self.pj[cfg.OBSERVATIONS][obs_id][cfg.TIME_OFFSET],
                                     3,
                                 )
 
@@ -272,8 +279,8 @@ def events_snapshots(self):
                                 try:
                                     if (
                                         start
-                                        > self.pj[cfg.OBSERVATIONS][obsId][cfg.MEDIA_INFO][cfg.LENGTH][
-                                            self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx]
+                                        > self.pj[cfg.OBSERVATIONS][obs_id][cfg.MEDIA_INFO][cfg.LENGTH][
+                                            self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx]
                                         ]
                                     ):
                                         continue
@@ -281,11 +288,13 @@ def events_snapshots(self):
                                     continue
 
                                 media_path = project_functions.full_path(
-                                    self.pj[cfg.OBSERVATIONS][obsId][cfg.FILE][nplayer][mediaFileIdx],
+                                    self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE][nplayer][mediaFileIdx],
                                     self.projectFileName,
                                 )
 
                                 vframes = int((stop - start) * mediafile_fps + time_interval * mediafile_fps * 2)
+                                if vframes == 0:
+                                    vframes = 1
 
                             else:
                                 continue
@@ -295,12 +304,12 @@ def events_snapshots(self):
                             f"-ss {start:.3f} "
                             f'-i "{media_path}" '
                             f"-vframes {vframes} "
-                            f'"{exportDir}{os.sep}'
-                            f"{util.safeFileName(obsId).replace(' ', '-')}"
+                            f'"{export_dir}{os.sep}'
+                            f"{util.safeFileName(obs_id).replace(' ', '-')}"
                             f"_PLAYER{nplayer}"
                             f"_{util.safeFileName(subject).replace(' ', '-')}"
                             f"_{util.safeFileName(behavior).replace(' ', '-')}"
-                            f'_{start:.3f}_%08d.{self.frame_bitmap_format.lower()}"'
+                            f'_{global_start:.3f}_%08d.{frame_bitmap_format}"'
                         )
 
                         logging.debug(f"ffmpeg command: {ffmpeg_command}")
@@ -308,6 +317,8 @@ def events_snapshots(self):
                         p = subprocess.Popen(ffmpeg_command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
                         out, _ = p.communicate()
 
+    self.statusbar.showMessage(f"Frames extracted in {export_dir}", 0)
+
 
 def extract_events(self):
     """
@@ -315,8 +326,8 @@ def extract_events(self):
     in case of point event, from -n to +n seconds are extracted (n is asked to user)
     """
 
-    _, selected_observations = select_observations.select_observations(
-        self.pj, cfg.MULTIPLE, windows_title="Select observations for extracting events"
+    _, selected_observations = select_observations.select_observations2(
+        self, cfg.MULTIPLE, windows_title="Select observations for extracting events"
     )
     if not selected_observations:
         return
@@ -328,7 +339,7 @@ def extract_events(self):
             live_images_obs_list.append(obs_id)
 
     if live_images_obs_list:
-        out = "The following observations are live observations or observation from images and will be removed from analysis<br><br>"
+        out = "The following observations are live observations or observation from pictures and will be removed from analysis<br><br>"
         out += "<br>".join(live_images_obs_list)
         results = dialog.Results_dialog()
         results.setWindowTitle(cfg.programName)
@@ -408,8 +419,8 @@ def extract_events(self):
         '-{globalStop}{extension}" '
     )
     """
-    ffmpeg_extract_command = '"{ffmpeg_bin}" -ss {start} -i "{input_}" -y -t {duration} {codecs} '
-    mem_command = ""
+    ffmpeg_extract_command: str = '"{ffmpeg_bin}" -ss {start} -i "{input_}" -y -t {duration} {codecs} '
+    mem_command: str = ""
     for obs_id in selected_observations:
 
         for nplayer in self.pj[cfg.OBSERVATIONS][obs_id][cfg.FILE]:
@@ -585,8 +596,16 @@ def extract_events(self):
                                 continue
 
                         new_file_name = pl.Path(export_dir) / pl.Path(
-                            f"{util.safeFileName(obs_id).replace(' ', '-')}_PLAYER{nplayer}_{util.safeFileName(subject).replace(' ', '-')}_{util.safeFileName(behavior)}_{globalStart}-{globalStop}"
-                        ).with_suffix(new_extension)
+                            (
+                                f"{util.safeFileName(obs_id).replace(' ', '-')}_"
+                                f"PLAYER{nplayer}_"
+                                f"{util.safeFileName(subject).replace(' ', '-')}_"
+                                f"{util.safeFileName(behavior)}_"
+                                f"{globalStart}-{globalStop}"
+                                f"{new_extension}"
+                            )
+                        )  # .with_suffix(new_extension)
+
                         if new_file_name.is_file():
                             if mem_command not in (cfg.OVERWRITE_ALL, cfg.SKIP_ALL):
                                 mem_command = dialog.MessageDialog(
@@ -620,4 +639,4 @@ def extract_events(self):
                         )
                         out, _ = p.communicate()
 
-    self.statusbar.showMessage(f"Media sequence extracted in {export_dir}", 0)
+    self.statusbar.showMessage(f"Media sequences extracted in {export_dir}", 0)
