@@ -44,11 +44,10 @@ from . import observation_operations
 
 def check_observation_exhaustivity(
     events: List[list],
-    # ethogram: list,
     state_events_list: list = [],
 ) -> float:
     """
-    check if observation is continous
+    calculate the observation exhaustivity
     if ethogram not empty state events list is determined else
 
     Args:
@@ -56,26 +55,11 @@ def check_observation_exhaustivity(
         ethogram (list):
     """
 
-    def interval_len(interval):
+    def interval_len(interval: I) -> dec:
         if interval.empty:
             return dec(0)
         else:
-            return sum([x.upper - x.lower for x in interval])
-
-    """
-    def interval_number(interval):
-        if interval.empty:
-            return dec(0)
-        else:
-            return len(interval)
-    """
-
-    """
-    if ethogram:
-        state_events_list: tuple = tuple(
-            (ethogram[x][cfg.BEHAVIOR_CODE] for x in ethogram if cfg.STATE in ethogram[x][cfg.TYPE].upper())
-        )
-    """
+            return dec(sum([x.upper - x.lower for x in interval]))
 
     events_interval: dict = {}
     mem_events_interval: dict = {}
@@ -125,6 +109,7 @@ def check_observation_exhaustivity(
             obs_real_dur = obs_theo_dur
 
         total_duration += obs_real_dur
+
     if len(events_interval) and obs_theo_dur:
         exhausivity_percent = total_duration / (len(events_interval) * obs_theo_dur) * 100
     else:
@@ -133,6 +118,27 @@ def check_observation_exhaustivity(
     return round(exhausivity_percent, 1)
 
 
+def check_observation_exhaustivity_pictures(obs) -> float:
+    """
+    check exhaustivity of coding for observations from pictures
+    """
+    if obs[cfg.TYPE] != cfg.IMAGES:
+        return -1
+    tot_images_number = 0
+
+    for dir_path in obs.get(cfg.DIRECTORIES_LIST, []):
+        result = util.dir_images_number(dir_path)
+        tot_images_number += result.get("number of images", 0)
+
+    if not tot_images_number:
+        return "No pictures found"
+
+    # list of paths of coded images
+    coded_images_number = len(set([x[cfg.PJ_OBS_FIELDS[cfg.IMAGES][cfg.IMAGE_PATH]] for x in obs[cfg.EVENTS]]))
+
+    return round(coded_images_number / tot_images_number * 100, 1)
+
+
 def behavior_category(ethogram: dict) -> Dict[str, str]:
     """
     returns a dictionary containing the behavioral category of each behavior
@@ -321,15 +327,10 @@ def check_state_events_obs(
 
                     for event in lst:
                         out += (
-                            "The behavior <b>{behavior}</b> {modifier} is not PAIRED for subject"
-                            ' "<b>{subject}</b>" at <b>{time}</b><br>'
-                        ).format(
-                            behavior=behavior,
-                            modifier=("(modifier " + event[1] + ") ") if event[1] else "",
-                            subject=subject if subject else cfg.NO_FOCAL_SUBJECT,
-                            time=memTime[str(event)]
-                            if time_format == cfg.S
-                            else util.seconds2time(memTime[str(event)]),
+                            f"The behavior <b>{behavior}</b> "
+                            f"{('(modifier ' + event[1] + ') ') if event[1] else ''} is not PAIRED "
+                            f'for subject "<b>{subject if subject else cfg.NO_FOCAL_SUBJECT}</b>" at '
+                            f"<b>{memTime[str(event)] if time_format == cfg.S else util.seconds2time(memTime[str(event)])}</b><br>"
                         )
 
     return (False, out) if out else (True, "No problem detected")
@@ -1094,7 +1095,7 @@ def full_path(path: str, project_file_name: str) -> str:
             return ""
 
 
-def observed_interval(observation: dict) -> tuple:
+def observed_interval(observation: dict) -> Tuple[dec, dec]:
     """
     Observed interval for observation
 
@@ -1108,19 +1109,13 @@ def observed_interval(observation: dict) -> tuple:
         return (dec("0.0"), dec("0.0"))
     if observation[cfg.TYPE] in (cfg.MEDIA, cfg.LIVE):
         return (
-            min(observation[cfg.EVENTS])[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]]["time"]],
-            max(observation[cfg.EVENTS])[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]]["time"]],
+            min(observation[cfg.EVENTS])[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]][cfg.TIME]],
+            max(observation[cfg.EVENTS])[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]][cfg.TIME]],
         )
     if observation[cfg.TYPE] == cfg.IMAGES:
-        events = [x[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]]["image index"]] for x in observation[cfg.EVENTS]]
+        events = [x[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]][cfg.IMAGE_INDEX]] for x in observation[cfg.EVENTS]]
 
         return (dec(min(events)), dec(max(events)))
-        """
-        return (
-            min(observation[cfg.EVENTS])[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]]["image index"]],
-            max(observation[cfg.EVENTS])[cfg.PJ_OBS_FIELDS[observation[cfg.TYPE]]["image index"]],
-        )
-        """
 
 
 def events_start_stop(ethogram: dict, events: list) -> list:
